# FHIR Metadata Vocabulary
This directory contains a static copy of the FHIR metadata vocabulary (fhir.ttl) and the FHIR W5 Ontology (who, what, why, where, when) that is used to organize FHIR resources.  This directory is strictly for testing purposes.

The official copies of these resources can be found at:
* fhir.ttl
    * latest version: [http://build.fhir.org/fhir.ttl](http://build.fhir.org/fhir.ttl)
    * STU3 version: [http://hl7.org/fhir/STU3/fhir.ttl](http://hl7.org/fhir/STU3/fhir.ttl)
* w5.ttl
    * latest version: [http://build.fhir.org/w5.ttl](http://build.fhir.org/w5.ttl)
    * STU3 version: [http://hl7.org/fhir/STU3/w5.ttl](http://hl7.org/fhir/STU3/w5.ttl)

The images in this directory are copies from the build server as of December 13, 2017.